# Installation

The instructions below will help you to properly install the generated package to the lavalite project.

## Location

Extract the package contents to the folder 

`/packages/ebuy/questions/`

## Composer

Add the below entries in the `composer.json` file's autoload section and run the command `composer dump-autoload` in terminal.

```json

...
     "autoload": {
         ...

        "classmap": [
            ...
            
            "packages/ebuy/questions/database/seeds",
            
            ...
        ],
        "psr-4": {
            ...
            
            "Ebuy\\Questions\\": "packages/ebuy/questions/src",
            
            ...
        }
    },
...

```

## Config

Add the entries in service provider in `config/app.php`

```php

...
    'providers'       => [
        ...
        
        Ebuy\Questions\Providers\QuestionsServiceProvider::class,
        
        ...
    ],

    ...

    'alias'             => [
        ...
        
        'Questions'  => Ebuy\Questions\Facades\Questions::class,
        
        ...
    ]
...

```

## Migrate

After service provider is set run the commapnd to migrate and seed the database.


    php artisan migrate
    php artisan db:seed --class=Ebuy\\QuestionsTableSeeder

## Publishing


**Publishing configuration**

    php artisan vendor:publish --provider="Ebuy\Questions\Providers\QuestionsServiceProvider" --tag="config"

**Publishing language**

    php artisan vendor:publish --provider="Ebuy\Questions\Providers\QuestionsServiceProvider" --tag="lang"

**Publishing views**

    php artisan vendor:publish --provider="Ebuy\Questions\Providers\QuestionsServiceProvider" --tag="view"


## URLs and APIs


### Web Urls

**Admin**

    http://path-to-route-folder/admin/questions/{modulename}

**User**

    http://path-to-route-folder/user/questions/{modulename}

**Public**

    http://path-to-route-folder/questions


### API endpoints

**List**
 
    http://path-to-route-folder/api/user/questions/{modulename}
    METHOD: GET

**Create**

    http://path-to-route-folder/api/user/questions/{modulename}
    METHOD: POST

**Edit**

    http://path-to-route-folder/api/user/questions/{modulename}/{id}
    METHOD: PUT

**Delete**

    http://path-to-route-folder/api/user/questions/{modulename}/{id}
    METHOD: DELETE

**Public List**

    http://path-to-route-folder/api/questions/{modulename}
    METHOD: GET

**Public Single**

    http://path-to-route-folder/api/questions/{modulename}/{slug}
    METHOD: GET