<?php

namespace Ebuy\Questions\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use App\Http\Requests\PublicRequest;
use Litepie\Repository\Filter\RequestFilter;
use Ebuy\Questions\Repositories\Eloquent\Filters\FaqPublicFilter;
use Ebuy\Questions\Repositories\Eloquent\Presenters\FaqListPresenter;
use Ebuy\Questions\Interfaces\FaqRepositoryInterface;

class FaqPublicController extends BaseController
{

    /**
     * Constructor.
     *
     * @return void
     */
    public function __construct(FaqRepositoryInterface $faq)
    {
        parent::__construct();
        $this->modules = $this->modules(config('ebuy.questions.modules'), 'questions', guard_url('questions'));
        $this->repository = $faq;

    }

    /**
     * Show faq's list.
     *
     * @return response
     */
    protected function index(PublicRequest $request)
    {

        $pageLimit = $request->input('pageLimit', config('database.pagination.limit'));
        $data = $this->repository
            ->pushFilter(RequestFilter::class)
            ->pushFilter(FaqPublicFilter::class)
            ->setPresenter(FaqListPresenter::class)
            ->simplePaginate($pageLimit)
            // ->withQueryString()
            ->toArray();

        extract($data);
        $modules = $this->modules;

        return $this->response->setMetaTitle(trans('questions::faq.names'))
            ->view('questions::public.faq.index')
            ->data(compact('data', 'meta', 'modules'))
            ->output();
    }


    /**
     * Show faq.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show(PublicRequest $request, $slug)
    {
        $data = $this->repository
            ->findBySlug($slug)
            ->toArray();
        $modules = $this->modules;

        return $this->response->setMetaTitle($data['name'] . trans('questions::faq.name'))
            ->view('questions::public.faq.show')
            ->data(compact('data', 'modules'))
            ->output();
    }

}
