<?php

namespace Ebuy\Questions\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use App\Http\Requests\PublicRequest;
use Litepie\Repository\Filter\RequestFilter;
use Ebuy\Questions\Repositories\Eloquent\Filters\QuestionPublicFilter;
use Ebuy\Questions\Repositories\Eloquent\Presenters\QuestionListPresenter;
use Ebuy\Questions\Interfaces\QuestionRepositoryInterface;

class QuestionPublicController extends BaseController
{

    /**
     * Constructor.
     *
     * @return void
     */
    public function __construct(QuestionRepositoryInterface $question)
    {
        parent::__construct();
        $this->modules = $this->modules(config('ebuy.questions.modules'), 'questions', guard_url('questions'));
        $this->repository = $question;

    }

    /**
     * Show question's list.
     *
     * @return response
     */
    protected function index(PublicRequest $request)
    {

        $pageLimit = $request->input('pageLimit', config('database.pagination.limit'));
        $data = $this->repository
            ->pushFilter(RequestFilter::class)
            ->pushFilter(QuestionPublicFilter::class)
            ->setPresenter(QuestionListPresenter::class)
            ->simplePaginate($pageLimit)
            // ->withQueryString()
            ->toArray();

        extract($data);
        $modules = $this->modules;

        return $this->response->setMetaTitle(trans('questions::question.names'))
            ->view('questions::public.question.index')
            ->data(compact('data', 'meta', 'modules'))
            ->output();
    }


    /**
     * Show question.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show(PublicRequest $request, $slug)
    {
        $data = $this->repository
            ->findBySlug($slug)
            ->toArray();
        $modules = $this->modules;

        return $this->response->setMetaTitle($data['name'] . trans('questions::question.name'))
            ->view('questions::public.question.show')
            ->data(compact('data', 'modules'))
            ->output();
    }

}
